@@ -99,6 +99,7 @@ def get_parser():
         mesh_numbers=None,
         modulation=None,
         moment_order=None,
+        pretend_real=False,
         primitive_axis=None,
         projection_direction=None,
         pwscf_mode=False,
@@ -304,6 +305,11 @@ def get_parser():
     parser.add_option(
         "--pm", dest="is_plusminus_displacements", action="store_true",
         help="Set plus minus displacements")
+    parser.add_option(
+        "--pr", "--pretend_real", dest="pretend_real", action="store_true",
+        help=("Use imaginary frequency as real for thermal property "
+              "calculation. For a testing purpose only, when a small "
+              "amount of imaginary branches obtained."))
     parser.add_option(
         "--pt", "--projected_thermal_property",
         dest="is_projected_thermal_properties", action="store_true",
@@ -319,9 +325,6 @@ def get_parser():
         help=("Direction of q-vector perturbation used for NAC at "
               "q->0, and group velocity for degenerate phonon "
               "mode in q-points mode"))
-    parser.add_option(
-        "--siesta", dest="siesta_mode",
-        action="store_true", help="Invoke Siesta mode")
     parser.add_option(
         "-q", "--quiet", dest="quiet", action="store_true",
         help="Print out smallest information")
@@ -334,6 +337,9 @@ def get_parser():
     parser.add_option(
         "--show_irreps", dest="show_irreps", action="store_true",
         help="Show IR-Reps along with characters")
+    parser.add_option(
+        "--siesta", dest="siesta_mode",
+        action="store_true", help="Invoke Siesta mode")
     parser.add_option(
         "--sigma", dest="sigma", type="string",
         help="Smearing width for DOS")
